import json
from native.json import json_stringify


class JSONWriter:

    def __init__(self, sheet_id):
        self.sheet_id = sheet_id
        self.fio = None

    def open(self):
        self.fio = open(self.sheet_id, 'w', encoding='utf-8')

    def close(self):
        if self.fio:
            self.fio.close()

    def __enter__(self):
        self.open()
        self.write('{')
        return self

    def __exit__(self, type, value, traceback):
        self.write('}')
        self.close()

    def write(self, string):
        return self.fio.write(string)

    def write_key_value(self, key, val, tail_comma=True):
        self.write('"%s":' % key)
        self.write_json(val)
        if tail_comma:
            self.write(',')

    def write_dict(self, dict_obj):
        for key, val in dict_obj.items():
            self.write_key_value(key, val, tail_comma=True)

    def write_json(self, json_obj):
        self.write(json_stringify(json_obj))


def export_json(json_obj, filename):
    with open(filename, 'w', encoding='utf-8') as f:
        json.dump(json_obj, f, separators=(',', ':'),
                  ensure_ascii=False, check_circular=False)
