<?php
namespace PhpOffice\PhpPresentation\Writer\PowerPoint2007;

use PhpOffice\Common\XMLWriter;

class PptNotesMasters extends AbstractSlide
{
    public function render()
    {
        $this->oZip->addFromString('ppt/notesMasters/_rels/notesMaster1.xml.rels', $this->writeNotesMasterRelationships());
        $this->oZip->addFromString('ppt/notesMasters/notesMaster1.xml', $this->writeNotesMaster());

        return $this->oZip;
    }

    protected function writeNotesMasterRelationships()
    {
        $masterCount = count($this->oPresentation->getAllMasterSlides());

        // Create XML writer
        $objWriter = new XMLWriter(XMLWriter::STORAGE_MEMORY);
        // XML header
        $objWriter->startDocument('1.0', 'UTF-8', 'yes');
        // Relationships
        $objWriter->startElement('Relationships');
        $objWriter->writeAttribute('xmlns', 'http://schemas.openxmlformats.org/package/2006/relationships');
        // FIXME
        $this->writeRelationship($objWriter, 1, 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme', '../theme/theme' . ($masterCount + 1) . '.xml');

        $objWriter->endElement();
        return $objWriter->getData();
    }

    protected function writeNotesMaster()
    {
        $id = 1;

        $objWriter = new XMLWriter(XMLWriter::STORAGE_MEMORY);
        $objWriter->startDocument('1.0', 'UTF-8', 'yes');

        // p:notesMaster
        $objWriter->startElement('p:notesMaster');
        $objWriter->writeAttribute('xmlns:a', 'http://schemas.openxmlformats.org/drawingml/2006/main');
        $objWriter->writeAttribute('xmlns:r', 'http://schemas.openxmlformats.org/officeDocument/2006/relationships');
        $objWriter->writeAttribute('xmlns:p', 'http://schemas.openxmlformats.org/presentationml/2006/main');

        // p:cSld
        $objWriter->startElement('p:cSld');

        // p:bg
        $objWriter->startElement('p:bg');
        // p:bgRef
        $objWriter->startElement('p:bgRef');
        $objWriter->writeAttribute('idx', '1001');
        // a:schemeClr
        $objWriter->startElement('a:schemeClr');
        $objWriter->writeAttribute('val', 'bg1');
        //>a:schemeClr
        $objWriter->endElement();
        //>p:bgRef
        $objWriter->endElement();
        //>p:bg
        $objWriter->endElement();

        // p:spTree
        $objWriter->startElement('p:spTree');
        // p:nvGrpSpPr
        $objWriter->startElement('p:nvGrpSpPr');
        // p:cNvPr
        $objWriter->startElement('p:cNvPr');
        $objWriter->writeAttribute('id', ++$id);
        $objWriter->writeAttribute('name', '');
        //>p:cNvPr
        $objWriter->endElement();
        $objWriter->writeElement('p:cNvGrpSpPr');
        $objWriter->writeElement('p:nvPr');
        //>p:nvGrpSpPr
        $objWriter->endElement();

        // p:grpSpPr
        $objWriter->startElement('p:grpSpPr');
        // a:xfrm
        $objWriter->startElement('a:xfrm');

        $objWriter->startElement('a:off');
        $objWriter->writeAttribute('x', 0);
        $objWriter->writeAttribute('y', 0);
        $objWriter->endElement();

        $objWriter->startElement('a:ext');
        $objWriter->writeAttribute('cx', 0);
        $objWriter->writeAttribute('cy', 0);
        $objWriter->endElement();

        $objWriter->startElement('a:chOff');
        $objWriter->writeAttribute('x', 0);
        $objWriter->writeAttribute('y', 0);
        $objWriter->endElement();

        $objWriter->startElement('a:chExt');
        $objWriter->writeAttribute('cx', 0);
        $objWriter->writeAttribute('cy', 0);
        $objWriter->endElement();

        //>a:xfrm
        $objWriter->endElement();
        //>p:grpSpPr
        $objWriter->endElement();
        //>p:spTree
        $objWriter->endElement();

        // p:extLst
        $objWriter->startElement('p:extLst');
        // p:ext
        $objWriter->startElement('p:ext');
        $objWriter->writeAttribute('uri', '{BB962C8B-B14F-4D97-AF65-F5344CB8AC3E}');
        // p14:creationId
        $objWriter->startElement('p14:creationId');
        $objWriter->writeAttribute('xmlns:p14', 'http://schemas.microsoft.com/office/powerpoint/2010/main');
        $objWriter->writeAttribute('val', '2658986512');
        //>p14:creationId
        $objWriter->endElement();
        //>p:ext
        $objWriter->endElement();
        //>p:extLst
        $objWriter->endElement();
        //>p:cSld
        $objWriter->endElement();

        // p:clrMap
        $objWriter->startElement('p:clrMap');
        $objWriter->writeAttribute('bg1', 'lt1');
        $objWriter->writeAttribute('tx1', 'dk1');
        $objWriter->writeAttribute('bg2', 'lt2');
        $objWriter->writeAttribute('tx2', 'dk2');
        $objWriter->writeAttribute('accent1', 'accent1');
        $objWriter->writeAttribute('accent2', 'accent2');
        $objWriter->writeAttribute('accent3', 'accent3');
        $objWriter->writeAttribute('accent4', 'accent4');
        $objWriter->writeAttribute('accent5', 'accent5');
        $objWriter->writeAttribute('accent6', 'accent6');
        $objWriter->writeAttribute('hlink', 'hlink');
        $objWriter->writeAttribute('folHlink', 'folHlink');
        //>p:clrMap
        $objWriter->endElement();

        $increase = 457200;
        // p:notesStyle
        $objWriter->startElement('p:notesStyle');
        for ($i = 1; $i < 10; $i++) {
            $objWriter->startElement('a:lvl' . $i . 'pPr');
            $objWriter->writeAttribute('marL', $increase * ($i - 1));
            $objWriter->writeAttribute('algn', 'l');
            //FIXME
            $objWriter->writeAttribute('defTabSz', '285750');
            $objWriter->writeAttribute('rtl', '0');
            $objWriter->writeAttribute('eaLnBrk', '1');
            $objWriter->writeAttribute('latinLnBrk', '0');
            $objWriter->writeAttribute('hangingPunct', '1');

            // a:defRPr
            $objWriter->startElement('a:defRPr');
            $objWriter->writeAttribute('sz', '1200');
            $objWriter->writeAttribute('kern', '1200');
            // a:solidFill
            $objWriter->startElement('a:solidFill');
            // a:schemeClr
            $objWriter->startElement('a:schemeClr');
            $objWriter->writeAttribute('val', 'tx1');
            //>a:schemeClr
            $objWriter->endElement();
            //>a:solidFill
            $objWriter->endElement();
            // a:latin
            $objWriter->startElement('a:latin');
            $objWriter->writeAttribute('typeface', '+mn-lt');
            //>a:latin
            $objWriter->endElement();
            // a:ea
            $objWriter->startElement('a:ea');
            $objWriter->writeAttribute('typeface', '+mn-ea');
            //>a:ea
            $objWriter->endElement();
            // a:cs
            $objWriter->startElement('a:cs');
            $objWriter->writeAttribute('typeface', '+mn-cs');
            //>a:cs
            $objWriter->endElement();
            //>a:defRPr
            $objWriter->endElement();
            //$objWriter->endElement();

            $objWriter->endElement();
        }
        //>p:notesStyle
        $objWriter->endElement();

        //>p:notesMaster
        $objWriter->endElement();
        return $objWriter->getData();
    }
}

?>
