<?php

namespace PhpOffice\PhpPresentation\Writer\ProseMirror;

use PhpOffice\PhpPresentation\Writer\ProseMirror\Master;

class BodyHolder extends Holder
{
    protected function setContent()
    {
        $slideType = ($this->slide instanceof Master) ? 'master' : 'layout';
        $this->type = 'body_' . $slideType . '_holder';

        $shape = new Node();
        $shape->type = 'body_' . $slideType . '_holder_shape';

        $textBlock = new Node();
        $textBlock->type = 'body_' . $slideType . '_holder_text_block';
        $this->setVerticalAlign($textBlock);
        $this->setTextBlockPadding($textBlock);
        $this->setBodyTextStyle(1, $textBlock);

        $shape->addContent($textBlock);
        $this->addContent($shape);
      }

    /**
     * Fill level style of body_holder
     * Every level is structured as:
     * order_1(item(holder_paragraph), item_1)
     * and then item_1 contains order_2
     */
     private function setBodyTextStyle($lv, $container)
     {
        $order = new Node();
        $order->type = 'order_' . $lv;
        $order->setAttr('order', $lv);

        $item = $this->createItem($lv);
        $order->addContent($item);

        $container->addContent($order);
        if (9 === $lv) {
            return;
        }
        $lvItem = new Node();
        $lvItem->type = 'item_' . $lv;
        $order->addContent($lvItem);

        $this->setBodyTextStyle($lv + 1, $lvItem);
    }

    private function createItem($lv)
    {
        $paragraph = new Paragraph();
        $paragraph->type = 'holder_paragraph';

        $styles = array();
        if ('master' === $this->slide->type) {
            $phpStyle = $this->slide->getBodyStyleAtLv($lv);
            if (isset($phpStyle)) {
                $paragraph->setStyles($phpStyle);
                $this->slide->getTextStyles($phpStyle->getFont(), $styles, true);
            }
        }

        $phpStyle = $this->phpShape->getListStyle()->getStyleAtLvl($lv);
        if (isset($phpStyle)) {
            $paragraph->setStyles($phpStyle);
            $this->slide->getTextStyles($phpStyle->getFont(), $styles, true);
        }

        $item = new Node();
        $item->type = 'item';

        if (0 < count($styles)) {
            $textMark = array();
            $this->slide->styleToMarks($styles, $textMark);
            $paragraph->setAttr('textMark', $textMark);
        }

        $item->addContent($paragraph);
        return $item;
    }
}

?>
