<?php

namespace PhpOffice\PhpPresentation\Writer\ProseMirror;

use PhpOffice\PhpPresentation\Shape\Chart;
use PhpOffice\PhpPresentation\Shape\Chart\Type\Area;
use PhpOffice\PhpPresentation\Shape\Chart\Type\Bar;
use PhpOffice\PhpPresentation\Shape\Chart\Type\Line as LineChart;
use PhpOffice\PhpPresentation\Shape\Chart\Type\Pie;
use PhpOffice\PhpPresentation\Shape\Chart\Type\Scatter;
use PhpOffice\PhpPresentation\Shape\Group;
use PhpOffice\PhpPresentation\Shape\RichText;
use PhpOffice\PhpPresentation\Shape\Line;
use PhpOffice\PhpPresentation\Shape\Drawing\Gd;

class ObjectGroup extends FloatingObject
{
    public $type = 'object_group';
    private $childOffsetX;
    private $childOffsetY;

    public function setContent()
    {
        $this->childOffsetX = $this->phpShape->getChildOffsetX();
        $this->childOffsetY = $this->phpShape->getChildOffsetY();

        $phpShapes = $this->phpShape->getShapeCollection();
        foreach ($phpShapes as $phpShape) {
            $box = $this->handleBox($phpShape);
            if (is_null($box)) {
                continue;
            }
            $this->addContent($box);
        }
    }

    protected function handleBox($phpShape)
    {
        if ($phpShape instanceof RichText) {
            if ($phpShape->isTextBox()) {
                $box = new TextBox($this->slide, $this);
            } else {
                $box = new ShapeBox($this->slide, $this);
            }
        } else if ($phpShape instanceof Line) {
            $box = new LineBox($this->slide, $this);
        } else if ($phpShape instanceof Gd) {
            $box = new ImageBox($this->slide, $this);
        } else if ($phpShape instanceof Group) {
            $box = new ObjectGroup($this->slide, $this);
        } else if ($phpShape instanceof Chart) {
            if (!$this->checkChartIsSupported($phpShape)) {
                return;
            }
            $box = new ChartBox($this->slide, $this);
        } else {
            return;
        }
        $box->setData($phpShape);

        return $box;
    }

    private function checkChartIsSupported($phpShape)
    {
        $phpPlotArea = $phpShape->getPlotArea();
        $phpTypes = $phpPlotArea->getTypes();
        foreach ($phpTypes as $phpType) {
            if ($phpType instanceof Area ||
                $phpType instanceof Bar ||
                $phpType instanceof LineChart ||
                $phpType instanceof Pie ||
                $phpType instanceof Scatter) {
                    continue;
            }
            return false;
        }
        if (0 === count($phpTypes)) {
            return false;
        }

        return true;
    }

    public function getChildOffsetX()
    {
        return $this->childOffsetX;
    }

    public function getChildOffsetY()
    {
        return $this->childOffsetY;
    }

    public function getChildScaleX()
    {
        return $this->phpShape->getChildScaleX();
    }

    public function getChildScaleY()
    {
        return $this->phpShape->getChildScaleY();
    }
}

?>
