<?php

namespace PhpOffice\PhpPresentation\Writer\ProseMirror;

use PhpOffice\PhpPresentation\Shape\RichText\BreakElement;
use PhpOffice\PhpPresentation\Shape\RichText\Paragraph as ShapeParagraph;
use PhpOffice\PhpPresentation\Style\Alignment;
use PhpOffice\PhpPresentation\Style\Font;

class Paragraph extends Node
{
    public $type = 'paragraph';
    protected $phpParagraph;
    protected $slide;
    private $listStyle;

    /*
     * for table
     */
    private $cellStyles = array();
    private $langFontMap = array();

    public function setSlide($slide)
    {
        $this->slide = $slide;
    }

    public function setListStyle($listStyle)
    {
        $this->listStyle = $listStyle;
    }

    public function setData($phpParagraph, $isSlideHolder = false, $isTextBox = false)
    {
        $this->phpParagraph = $phpParagraph;
        $this->isSlideHolder = $isSlideHolder;
        $this->isTextBox = $isTextBox;
        $styles = array();

        $paraStyles = array();
        $paraLangFontMap = array();
        $paraTextMark = array();

        if ($this->slide) {
            //default style defined in ppt/presentation
            if (!$isSlideHolder) {
                $level = $phpParagraph->getAlignment()->getLevel() + 1;
                $defListStyle = $this->slide->getDefaultListStyle();
                if (isset($defListStyle)) {
                    $defStyle = $defListStyle->getStyleAtLvl($level);
                    if (isset($defStyle)) {
                        $this->slide->getTextStyles($defStyle->getFont(), $paraStyles);
                        $defLangFontMap = $defStyle->getFont()->getLangFontMap();
                        foreach ($defLangFontMap as $lang => $typeface) {
                            if (false !== strpos($typeface, '+mj-')) {
                                $typeface = $this->slide->getSchemeFont(true, $lang);
                            } else if (false !== strpos($typeface, '+mn-')) {
                                $typeface = $this->slide->getSchemeFont(false, $lang);
                            }
                            $defLangFontMap[$lang] = $typeface;
                        }
                        $this->setLangFontMap($defLangFontMap, $paraLangFontMap);
                    }
                }
            }

            //list style defined in txBody, a shapewise style setting 
            if (isset($this->listStyle)) {
                $this->slide->getTextStyles($this->listStyle->getFont(), $paraStyles);
                $this->setLangFontMap($this->listStyle->getFont()->getLangFontMap(), $paraLangFontMap);
            }

            $this->slide->getTextStyles($this->phpParagraph->getFont(), $paraStyles);
            $this->setLangFontMap($this->phpParagraph->getFont()->getLangFontMap(), $paraLangFontMap);
        }

        if (isset($this->listStyle)) {
            $this->setStyles($this->listStyle);
        }
        $this->setStyles($this->phpParagraph);

        $phpTexts = $this->phpParagraph->getRichTextElements();
        foreach ($phpTexts as $phpText) {
            if ($phpText instanceof BreakElement) {
                $hardBreak = new \stdClass();
                $hardBreak->type = 'hard_break';
                $this->addContent($hardBreak);
                continue;
            }
            $text = new Text();
            $textMark = array();

            $plainText = str_replace("\t", "    ", $phpText->getText());
            $text->text = $plainText;
            if (0 === strlen($text->text)) {
                continue;
            }
            $textStyles = array();

            $hyperlink = $phpText->getHyperlink();
            if ('' !== $hyperlink->getAction() || '' !== $hyperlink->getUrl()) {
                $mark = new \stdClass();
                $mark->_ = 'link';
                if (!$hyperlink->isInternal()) {
                    $mark->href = $hyperlink->getUrl();
                } else if (!$hyperlink->isRelative()) {
                    $slideNum = $hyperlink->getSlideNumber();
                    $mark->href = '#' . $this->slide->getPresentation()->getSlideId($slideNum - 1);
                } else {
                    switch ($hyperlink->getRelativePos()) {
                        case 'firstslide':
                            $slideId = $this->slide->getPresentation()->getSlideId(0);
                            break;
                        case 'lastslide':
                            $slideId = $this->slide->getPresentation()->getLastSlideId();
                            break;
                        case 'nextslide':
                            $slideId = $this->slide->getPresentation()->getSlideId($this->slide->getIdx() + 1);
                            break;
                        case 'previousslide':
                            $slideId = $this->slide->getPresentation()->getSlideId($this->slide->getIdx() - 1);
                            break;
                        default:
                            $slideId = '';
                            break;
                    }
                    $mark->href = '#' . $slideId;
                }
                $mark->text = $text->text;
                array_push($textMark, $mark);

                $textStyles['color'] = '#' . $this->slide->getColor($this->slide->getSchemeColor('hlink'));
            }
            $textLangFontMap = array();

            Utils::getTextStyles($phpText->getFont(), $textStyles, false, $this->slide);
            $this->setLangFontMap($phpText->getFont()->getLangFontMap(), $textLangFontMap);

            $this->mergeArray($this->cellStyles, $textStyles);
            $this->mergeArray($paraStyles, $textStyles);
            $this->mergeArray($paraLangFontMap, $textLangFontMap);

            if (!isset($firstTextStyles)) {
                $firstTextStyles = $textStyles;
            }
            Utils::styleToMarks($textStyles, $textMark);

            $m = mb_strlen($text->text,'utf-8');
            $s = strlen($text->text);
            $lang = 'a:latin';
            if ($m !== $s) {
                $lang = 'a:ea';
            }
            $typeface = $textLangFontMap[$lang];
            if (isset($typeface) && '' != $typeface) {
                $fontFamilyMark = new \stdClass();
                $fontFamilyMark->_ = 'font_family';
                $fontFamilyMark->value = $typeface;
                array_push($textMark, $fontFamilyMark);
            }
            $text->marks = $textMark;

            $this->addContent($text);
        }

        if (!isset($firstTextStyles)) {
            $font = $this->phpParagraph->getFont();
            $firstTextStyles = array();
            if (Font::STATE_ON === $font->getBold()) {
                $firstTextStyles['strong'] = true;
            }
            if (Font::STATE_ON === $font->getItalic()) {
                $firstTextStyles['em'] = true;
            }
            if (0 !== $font->getSize()) {
                $firstTextStyles['font_size'] = $font->getSize() . 'pt';
            }
        }
        if ($this->slide) {
            $bulletColor = $this->phpParagraph->getBulletStyle()->getBulletColor();
            if (!is_null($bulletColor)) {
                $firstTextStyles['color'] = '#' . $this->slide->getColor($bulletColor);
            }
            $this->slide->styleToMarks($firstTextStyles, $paraTextMark);
            $this->setAttr('textMark', $paraTextMark);
        }

        return $firstTextStyles;
    }

    public function setCellStyles($cellStyles)
    {
        if (!is_array($cellStyles)) {
            return;
        }
        $this->cellStyles = $cellStyles;
    }

    private function setAlignment($phpParagraph)
    {
        if (Alignment::HORIZONTAL_NONE === $phpParagraph->getAlignment()->getHorizontal()) {
            return;
        }
        $alignment = 'left';
        switch ($phpParagraph->getAlignment()->getHorizontal()) {
            case 'r':
                $alignment = 'right';
                break;
            case 'ctr':
                $alignment = 'center';
                break;
            case 'just':
                $alignment = 'justify';
                break;
            case 'l':
            default:
                break;
        }
        $this->setAttr('textAlign', $alignment);
    }

    public function setStyles($phpParagraph)
    {
        $this->setAlignment($phpParagraph);

        if (ShapeParagraph::LINE_SPACE_NONE !== $phpParagraph->getLineSpacing()) {
            $lineHeight = $phpParagraph->getLineSpacing() / 100000;
            if (1 > $lineHeight) {
                $lineHeight = 1;
            }
            $this->setAttr('lineHeight', (string) $lineHeight);
        } else if ($this->isTextBox) {
            $this->setAttr('lineHeight', '1');
        }

        if (ShapeParagraph::SPACE_BEF_AFT_NONE !== $phpParagraph->getSpaceBefore()) {
            $this->setAttr('paddingTop', ($phpParagraph->getSpaceBefore() / 100) . 'pt');
        }
        if (ShapeParagraph::SPACE_BEF_AFT_NONE !== $phpParagraph->getSpaceAfter()) {
            $this->setAttr('paddingBottom', ($phpParagraph->getSpaceAfter() / 100) . 'pt');
        }
    }

    private function setLangFontMap($langFontMap, &$resultLangFontMap)
    {
        foreach ($langFontMap as $lang => $typeface) {
            $resultLangFontMap[$lang] = $typeface;
        }
    }

    private function mergeArray($srcArray, &$destArray)
    {
        foreach ($srcArray as $key => $value) {
            if (!key_exists($key, $destArray)) {
                $destArray[$key] = $value;
            }
        }
    }
}

?>
