<?php

namespace PhpOffice\PhpPresentation\Writer\ProseMirror;

class Shape extends Node
{
    private static $shapeNameMapping = array(
        'rect'              => 'rect',
        'roundRect'         => 'rect_round',
        'snip1Rect'         => 'rect_single_snip',
        'snip2SameRect'     => 'rect_snip_same_side',
        'snip2DiagRect'     => 'rect_snip_diagonal',
        'snipRoundRect'     => 'rect_snip_round',
        'round1Rect'        => 'rect_single_round',
        'round2SameRect'    => 'rect_round_same_side',
        'round2DiagRect'    => 'rect_round_diagonal',
        'ellipse'           => 'ellipse',
        'triangle'          => 'triangle',
        'rtTriangle'        => 'right_triangle',
        'parallelogram'     => 'parallelogram',
        'trapezoid'         => 'trapezoid',
        'diamond'           => 'diamond',
        'pentagon'          => 'pentagon',
        'hexagon'           => 'hexagon',
        'heptagon'          => 'heptagon',
        'octagon'           => 'octagon',
        'decagon'           => 'decagon',
        'dodecagon'         => 'dodecagon',
        'pie'               => 'pie',
        'chord'             => 'chord',
        'frame'             => 'rect_frame',
        'halfFrame'         => 'half_frame',
        'corner'            => 'l_shape',
        'diagStripe'        => 'diagonal_stripe',
        'plus'              => 'cross',
        'plaque'            => 'plaque',
        'can'               => 'can',
        'cube'              => 'cube',
        'bevel'             => 'bevel',
        'donut'             => 'donut',
        'blockArc'          => 'block_arc',
        'foldedCorner'      => 'folded_corner',
        'lightningBolt'     => 'lightning_bolt',
        'moon'              => 'moon',
        'star4'             => '4_point_star',
        'rightArrow'        => 'arrow',
        'leftArrow'         => 'arrow_left',
        'upArrow'           => 'arrow_up',
        'downArrow'         => 'arrow_down',
        'leftRightArrow'    => 'arrow_left_right',
        'upDownArrow'       => 'arrow_up_down',
        'stripedRightArrow' => 'arrow_striped',
        'notchedRightArrow' => 'arrow_notched',
        'homePlate'         => 'arrow_pentagon',
        'chevron'           => 'arrow_chevron',
        'line'              => 'line',
        'straightConnector1'=> 'line',
        'bentConnector2'    => 'line',  // FIXME: workaround
        'bentConnector3'    => 'connect_line',
        'bentConnector4'    => 'connect_line',  // FIXME: workaround
        'bentConnector5'    => 'connect_line'  // FIXME: workaround
    );

    public $type = 'shape';
    protected $defaultShape = 'rect';
    protected $shapeTypeAttr = 'shape_type';

    static public function checkShapeSupport($msShapeType)
    {
        return array_key_exists($msShapeType, self::$shapeNameMapping);
    }

    public function setShapeType($msShapeType)
    {
        //mapping
        if (array_key_exists($msShapeType, self::$shapeNameMapping)) {
            $shapeType = self::$shapeNameMapping[$msShapeType];
        } else {
            $shapeType = $defaultShape;
        }
        $this->setAttr($this->shapeTypeAttr, $shapeType);
    }

    public function setCustPoints($custPoints)
    {
        if (!is_null($custPoints)) {
            $this->setAttr('cust_points', $custPoints);
        }
    }
}

?>
